@@ -30,6 +30,8 @@ struct i2c_platform_data {
 #define I2C_NAME_SIZE	20
 
 #define I2C_M_RD		0x0001	/* read data, from slave to master */
+#define I2C_M_TEN               0x0010  /* this is a ten bit chip address */
+#define I2C_M_IGNORE_NAK        0x1000  /* if I2C_FUNC_PROTOCOL_MANGLING */
 
 /**
  * struct i2c_msg - an I2C transaction segment beginning with START
